==> moodle-1.6.3p0.tgz: moodle/lang/en_utf8/exercise.php <==
<?PHP // $Id: exercise.php,v 1.1 2006/02/06 09:28:54 moodler Exp $ 
      // exercise.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005010100)


$string['absent'] = 'Absent';
$string['accumulative'] = 'Accumulative';
$string['action'] = 'Action';
$string['ago'] = '$a ago';
$string['amend'] = 'Amend';
$string['amendassessmentelements'] = 'Amend Assessment Elements';
$string['amendtitle'] = 'Amend Title';
$string['analysis'] = 'Analysis';
$string['assess'] = 'Assess';
$string['assessed'] = 'Assessed';
$string['assessment'] = 'Assessment';
$string['assessmentby'] = 'Assessment by $a';
$string['assessmentform'] = 'Assessment Form';
$string['assessmentmadebythe'] = 'Assessment made by the $a';
$string['assessmentofthissubmission'] = 'Assessment of this submission';
$string['assessments'] = 'Assessments';
$string['atthisstageyou'] = 'At this stage you have completed an assessment.<br />You may want to revise your work in the light of that assessment.<br /> If you do that please remember to also revise your assessment.<br /> You can do this by clicking on the Re-assess link given below.';
$string['awaitingassessmentbythe'] = 'Awaiting Assessment by the $a';
$string['clearlateflag'] = 'Clear Late Flag';
$string['comment'] = 'Comment';
$string['comparisonofassessments'] = 'Comparison of Assessments';
$string['confirmdeletionofthisitem'] = 'Confirm Deletion of this $a';
$string['correct'] = 'Correct';
$string['count'] = 'Count';
$string['criterion'] = 'Criterion';
$string['deadline'] = 'Deadline';
$string['deadlineis'] = 'The Deadline is $a';
$string['delete'] = 'Delete';
$string['deletesubmissionwarning'] = 'Warning: there $a assessments associated with this submission.<br />
    It is strongly suggested that this submission is NOT deleted.';
$string['deleting'] = 'Deleting';
$string['description'] = 'Description';
$string['descriptionofexercise'] = 'In an Exercise Assignment the description of the exercise or task to be done by the $a is put into a Word document or HTML file. This file is uploaded into the exercise before the assignment is opened up to the $a. It is also possible to create a set of variants on the same exercise or task, again as Word documents or HTML files, and upload these into the exercise before it is opened up to the $a.';
$string['detailsofassessment'] = 'Details of Assessment';
$string['displayoffinalgrades'] = 'Display of Final Grades';
$string['doubleupload'] = 'Warning: this submission has probably been sent twice. Go to the Administration page, check for two submissions from this user within a short time period. Delete one of these submissions before proceeding.';
$string['duedate'] = 'Due Date';
$string['edit'] = 'Edit';
$string['editingassessmentelements'] = 'Editing Assessment Elements';
$string['element'] = 'Element';
$string['elementweight'] = 'Element Weight';
$string['enterpassword'] = 'Enter Password';
$string['entriessaved'] = 'Entries Saved';
$string['errorbanded'] = 'Error Banded';
$string['excellent'] = 'Excellent';
$string['exerciseassessments'] = 'Exercise Assessments';
$string['exercisefeedback'] = 'Exercise Feedback';
$string['exercisesubmissions'] = 'Exercise Submissions';
$string['fair'] = 'Fair';
$string['generalcomment'] = 'General comment';
$string['good'] = 'Good';
$string['gradeassessment'] = 'Grade Assessment';
$string['gradeforassessment'] = 'Grade for Assessment';
$string['gradeforstudentsassessment'] = 'Grade for $a Assessment';
$string['gradeforsubmission'] = 'Grade for Submission';
$string['gradetable'] = 'Grade Table';
$string['gradinggrade'] = 'Grading Grade';
$string['gradingstrategy'] = 'Grading Strategy';
$string['handlingofmultiplesubmissions'] = 'Handling of Multiple Submissions';
$string['hidenamesfromstudents'] = 'Hide Names from Students';
$string['incorrect'] = 'Incorrect';
$string['late'] = 'Late';
$string['lax'] = 'Lax';
$string['leaguetable'] = 'League Table of Submitted Work';
$string['mail1'] = 'Your assignment \'$a\' has been assessed by';
$string['mail2'] = 'The comments and grade can be seen in the Exercise Assignment \'$a\'';
$string['mail3'] = 'You can see it in your Exercise Assignment';
$string['mail6'] = 'Your assessment of the assignment \'$a\' has by reviewed';
$string['mail7'] = 'The comments given by the $a can be seen in the Exercise Assignment ';
$string['managingassignment'] = 'Managing the Exercise';
$string['maximum'] = 'Maximum';
$string['maximumgradeforstudentassessments'] = 'Maximum Grade for Student Assessments: $a';
$string['maximumgradeforsubmissions'] = 'Maximum Grade for Submissions: $a';
$string['maximumsize'] = 'Maximum Size';
$string['mean'] = 'Mean';
$string['minimum'] = 'Minumum';
$string['modulename'] = 'Exercise';
$string['modulenameplural'] = 'Exercises';
$string['movingtophase'] = 'Moving to Phase $a';
$string['multiplesubmissions'] = 'Multiple Submissions';
$string['noexercisedescriptionssubmitted'] = 'No Exercise Descriptions Submitted';
$string['nosubmissions'] = 'No Submissions';
$string['notassessedyet'] = 'Not Assessed Yet';
$string['notavailable'] = 'Not Available';
$string['noteonassessmentelements'] = 'Note that grading is broken down into a number of \'Assessment Elements\'.<br />
	This makes the grading easier and more consistent. As teacher you must add these <br />
	Elements before making the assignment available to students. This is done by<br />
	clicking on the assignment in the course, if no elements are present you will be asked<br />
	to add them. You can change the number of elements using the Edit Assignment screen,<br />
	the elements themselves can be amended from the \"Managing Assignment\" screen. ';
$string['noteongradinggrade'] = 'This grade is a measure of how well your assessment agrees with the assessment of <br />
    your work by the $a. The higher the grade the closer the agreement.';
$string['noteonstudentassessments'] = '{Grade from student / Grading Grade for assessment}';
$string['notgraded'] = 'Not Graded';
$string['notitlegiven'] = 'No Title Given';
$string['numberofassessmentelements'] = 'Number of Comments, Assessment Elements, Grade Bands, Criterion Statments or Categories in a Rubric';
$string['numberofcriterionelements'] = 'Number of Criterion Elements must be greater than one.';
$string['numberofentries'] = 'Number of Entries';
$string['numberofentriesinleaguetable'] = 'Number of Entries in League Table';
$string['numberofnegativeresponses'] = 'Number of Negative Responses';
$string['onesubmission'] = 'One Submission';
$string['optionaladjustment'] = 'Optional Adjustment';
$string['overallgrade'] = 'Overall Grade';
$string['passwordprotectedexercise'] = 'Password Protected Exercise';
$string['phase'] = 'Phase';
$string['phase1'] = 'Set Up Exercise';
$string['phase1short'] = 'Set Up';
$string['phase2'] = 'Allow $a Assessments and Submissions';
$string['phase2short'] = 'Open';
$string['phase3'] = 'Show Overall Grades and League Table';
$string['phase3short'] = 'Display';
$string['pleasegradetheassessment'] = 'Please Grade the Assessment of this Piece of Work by $a';
$string['pleasemakeyourownassessment'] = 'Please make your own Assessment of the Piece of Work from $a. <br />Note that the Assessment Form is initially displayed with the Student\'s assessment.<br /> You should make any amendments you think necessary and then click on one <br />of the buttons at the foot of the page.';
$string['pleasesubmityourwork'] = 'Please submit your Work using this Form';
$string['pleaseusethisform'] = 'Please complete this form when you have <br />finished the instructions in the exercise shown below.';
$string['pleaseviewtheexercise'] = 'Please view the exercise given below by clicking on it\'s title.<br />You should follow the instructions in this exercise. <br />When you are happy that you have completed the exercise<br /> successfully you should click on Assess (or Re-assess) link in <br />the box below. When you have done this assessment you will <br />be shown further instructions on submitting your work.';
$string['poor'] = 'Poor';
$string['present'] = 'Present';
$string['reasonforadjustment'] = 'General Comment/Reason for Adjustment';
$string['reassess'] = 'Re-assess';
$string['regradestudentassessments'] = 'Re-grade Student assessments';
$string['resubmissionfor'] = 'Resubmission for $a';
$string['resubmitnote'] = '* means that the $a is allowed to redo this submission. <br /> This flag can be given to any submission by re-assessing it and clicking <br />on the <b>Allow $a to Re-submit</b> button. <br />The student can resubmit when this flag is present on <b>any</b> of their submissions.';
$string['rubric'] = 'Rubric';
$string['savedok'] = 'Saved OK';
$string['saveentries'] = 'Save Entries';
$string['savemyassessment'] = 'Save my Assessment';
$string['saveweights'] = 'Save Weights';
$string['scale10'] = 'Score out of 10';
$string['scale100'] = 'Score out of 100';
$string['scale20'] = 'Score out of 20';
$string['scalecorrect'] = '2 point Correct/Incorrect scale';
$string['scaleexcellent4'] = '4 point Excellent/Very Poor scale';
$string['scaleexcellent5'] = '5 point Excellent/Very Poor scale';
$string['scaleexcellent7'] = '7 point Excellent/Very Poor scale';
$string['scalegood3'] = '3 point Good/Poor scale';
$string['scalepresent'] = '2 point Present/Absent scale';
$string['scaleyes'] = '2 point Yes/No scale';
$string['specimenassessmentform'] = 'Specimen Assessment Form';
$string['standarddeviation'] = 'Standard Deviation';
$string['strict'] = 'Strict';
$string['studentallowedtoresubmit'] = '$a ALLOWED to re-submit';
$string['studentassessments'] = '$a Assessments';
$string['studentnotallowed'] = '$a NOT allowed to re-submit (or not needed)';
$string['studentsubmissions'] = '$a Submissions';
$string['studentsubmissionsforassessment'] = '$a Student Submissions for Assessment';
$string['submission'] = 'Submission';
$string['submissions'] = 'Submissions';
$string['submissionsnowclosed'] = 'Submissions now closed - Submission deadline has passed';
$string['submitexercisedescription'] = 'Submit Exercise Description';
$string['submitted'] = 'Submitted';
$string['submittedby'] = 'Submitted by';
$string['suggestedgrade'] = 'Suggested Grade';
$string['teacherassessment'] = '$a Assessment';
$string['teacherassessmenttable'] = '$a Assessment Table';
$string['teacherscomment'] = 'Teacher\'s Comment';
$string['theexercise'] = 'The Exercise';
$string['theexerciseandthesubmissionby'] = 'The Exercise and the Submission by $a';
$string['thegradeis'] = 'The Grade is $a';
$string['thereisfeedbackfromthe'] = 'There is feedback from the $a';
$string['thisisaresubmission'] = 'This is a Re-submission by $a.<br />Your assessment of their previous submission is shown. <br />After looking at the new submission, please Amend this assessment<br /> and click on one of the buttons at the foot of the page.';
$string['title'] = 'Title';
$string['typeofscale'] = 'Type of Scale';
$string['unassessed'] = '$a Unassessed';
$string['ungradedstudentassessments'] = '$a Ungraded Student Assessments';
$string['usemaximum'] = 'Use Maximum';
$string['usemean'] = 'Use Mean';
$string['usepassword'] = 'Use Password';
$string['verylax'] = 'Very Lax';
$string['verypoor'] = 'Very Poor';
$string['verystrict'] = 'Very Strict';
$string['view'] = 'View';
$string['viewteacherassessment'] = 'View $a Assessment';
$string['warningonamendingelements'] = 'WARNING: There are submitted assessments. <br />Do NOT change the number of elements, the scale types or the element weights.';
$string['weightederrorcount'] = 'Weighted Error Count: $a';
$string['weightforgradingofassessments'] = 'Weight for Grading of Assessments';
$string['weightforteacherassessments'] = 'Weight for $a Assessments';
$string['weights'] = 'Weights';
$string['weightssaved'] = 'Weights Saved';
$string['weightsusedforoverallgrade'] = 'Weights used for Overall Grade';
$string['wrongpassword'] = 'Incorrect password for this Exercise';
$string['yourassessment'] = 'Your Assessment';
$string['yourfeedbackgoeshere'] = 'Your Feedback goes Here';
$string['yoursubmission'] = 'Your Submission';

?>

==> moodle-1.9.16.tgz: moodle/lang/en_utf8/exercise.php <==
<?PHP // $Id: exercise.php,v 1.4.8.1 2008/10/02 14:39:13 poltawski Exp $ 
      // exercise.php - created with Moodle 1.7 beta + (2006101003)


$string['absent'] = 'Absent';
$string['accumulative'] = 'Accumulative';
$string['action'] = 'Action';
$string['ago'] = '$a ago';
$string['amend'] = 'Amend';
$string['amendassessmentelements'] = 'Amend Assessment Elements';
$string['amendtitle'] = 'Amend Title';
$string['analysis'] = 'Analysis';
$string['assess'] = 'Assess';
$string['assessed'] = 'Assessed';
$string['assessment'] = 'Assessment';
$string['assessmentby'] = 'Assessment by $a';
$string['assessmentform'] = 'Assessment Form';
$string['assessmentmadebythe'] = 'Assessment made by the $a';
$string['assessmentofthissubmission'] = 'Assessment of this submission';
$string['assessments'] = 'Assessments';
$string['atthisstageyou'] = 'At this stage you have completed an assessment.<br />You may want to revise your work in the light of that assessment.<br /> If you do that please remember to also revise your assessment.<br /> You can do this by clicking on the Re-assess link given below.';
$string['awaitingassessmentbythe'] = 'Awaiting Assessment by the $a';
$string['clearlateflag'] = 'Clear Late Flag';
$string['comment'] = 'Comment';
$string['comparisonofassessments'] = 'Comparison of Assessments';
$string['confirmdeletionofthisitem'] = 'Confirm Deletion of this $a';
$string['correct'] = 'Correct';
$string['count'] = 'Count';
$string['criterion'] = 'Criterion';
$string['deadline'] = 'Deadline';
$string['deadlineis'] = 'The Deadline is $a';
$string['delete'] = 'Delete';
$string['deletesubmissionwarning'] = 'Warning: there $a assessments associated with this submission.<br />
    It is strongly suggested that this submission is NOT deleted.';
$string['deleting'] = 'Deleting';
$string['description'] = 'Description';
$string['descriptionofexercise'] = 'In an Exercise Assignment the description of the exercise or task to be done by the $a is put into a Word document or HTML file. This file is uploaded into the exercise before the assignment is opened up to the $a. It is also possible to create a set of variants on the same exercise or task, again as Word documents or HTML files, and upload these into the exercise before it is opened up to the $a.';
$string['detailsofassessment'] = 'Details of Assessment';
$string['displayoffinalgrades'] = 'Display of Final Grades';
$string['doubleupload'] = 'Warning: this submission has probably been sent twice. Go to the Administration page, check for two submissions from this user within a short time period. Delete one of these submissions before proceeding.';
$string['duedate'] = 'Due Date';
$string['edit'] = 'Edit';
$string['editingassessmentelements'] = 'Editing Assessment Elements';
$string['element'] = 'Element';
$string['elementweight'] = 'Element Weight';
$string['enterpassword'] = 'Enter Password';
$string['entriessaved'] = 'Entries Saved';
$string['errorbanded'] = 'Error Banded';
$string['excellent'] = 'Excellent';
$string['exercise:assess'] = 'Assess exercises';
$string['exerciseassessments'] = 'Exercise Assessments';
$string['exercisefeedback'] = 'Exercise Feedback';
$string['exercisesubmissions'] = 'Exercise Submissions';
$string['fair'] = 'Fair';
$string['generalcomment'] = 'General comment';
$string['good'] = 'Good';
$string['gradeassessment'] = 'Grade Assessment';
$string['gradeforassessment'] = 'Grade for Assessment';
$string['gradeforstudentsassessment'] = 'Grade for $a Assessment';
$string['gradeforsubmission'] = 'Grade for Submission';
$string['gradetable'] = 'Grade Table';
$string['gradinggrade'] = 'Grading Grade';
$string['gradingstrategy'] = 'Grading Strategy';
$string['handlingofmultiplesubmissions'] = 'Handling of Multiple Submissions';
$string['hidenamesfromstudents'] = 'Hide Names from Students';
$string['incorrect'] = 'Incorrect';
$string['late'] = 'Late';
$string['lax'] = 'Lax';
$string['leaguetable'] = 'League Table of Submitted Work';
$string['mail1'] = 'Your assignment \'$a\' has been assessed by';
$string['mail2'] = 'The comments and grade can be seen in the Exercise Assignment \'$a\'';
$string['mail3'] = 'You can see it in your Exercise Assignment';
$string['mail6'] = 'Your assessment of the assignment \'$a\' has by reviewed';
$string['mail7'] = 'The comments given by the $a can be seen in the Exercise Assignment';
$string['managingassignment'] = 'Managing the Exercise';
$string['maximum'] = 'Maximum';
$string['maximumgradeforstudentassessments'] = 'Maximum Grade for Student Assessments: $a';
$string['maximumgradeforsubmissions'] = 'Maximum Grade for Submissions: $a';
$string['maximumsize'] = 'Maximum Size';
$string['mean'] = 'Mean';
$string['minimum'] = 'Minumum';
$string['modulename'] = 'Exercise';
$string['modulenameplural'] = 'Exercises';
$string['movingtophase'] = 'Moving to Phase $a';
$string['multiplesubmissions'] = 'Multiple Submissions';
$string['noexercisedescriptionssubmitted'] = 'No Exercise Descriptions Submitted';
$string['nosubmissions'] = 'No Submissions';
$string['notassessedyet'] = 'Not Assessed Yet';
$string['notavailable'] = 'Not Available';
$string['noteonassessmentelements'] = 'Note that grading is broken down into a number of \'Assessment Elements\'.<br />
    This makes the grading easier and more consistent. As teacher you must add these <br />
    Elements before making the assignment available to students. This is done by<br />
    clicking on the assignment in the course, if no elements are present you will be asked<br />
    to add them. You can change the number of elements using the Edit Assignment screen,<br />
    the elements themselves can be amended from the \"Managing Assignment\" screen.';
$string['noteongradinggrade'] = 'This grade is a measure of how well your assessment agrees with the assessment of <br />
    your work by the $a. The higher the grade the closer the agreement.';
$string['noteonstudentassessments'] = '{Grade from student / Grading Grade for assessment}';
$string['notgraded'] = 'Not Graded';
$string['notitlegiven'] = 'No Title Given';
$string['numberofassessmentelements'] = 'Number of Comments, Assessment Elements, Grade Bands, Criterion Statements or Categories in a Rubric';
$string['numberofcriterionelements'] = 'Number of Criterion Elements must be greater than one.';
$string['numberofentries'] = 'Number of Entries';
$string['numberofentriesinleaguetable'] = 'Number of Entries in League Table';
$string['numberofnegativeresponses'] = 'Number of Negative Responses';
$string['onesubmission'] = 'One Submission';
$string['optionaladjustment'] = 'Optional Adjustment';
$string['overallgrade'] = 'Overall Grade';
$string['passwordprotectedexercise'] = 'Password Protected Exercise';
$string['phase'] = 'Phase';
$string['phase1'] = 'Set Up Exercise';
$string['phase1short'] = 'Set Up';
$string['phase2'] = 'Allow $a Assessments and Submissions';
$string['phase2short'] = 'Open';
$string['phase3'] = 'Show Overall Grades and League Table';
$string['phase3short'] = 'Display';
$string['pleasegradetheassessment'] = 'Please Grade the Assessment of this Piece of Work by $a';
$string['pleasemakeyourownassessment'] = 'Please make your own Assessment of the Piece of Work from $a. <br />Note that the Assessment Form is initially displayed with the Student\'s assessment.<br /> You should make any amendments you think necessary and then click on one <br />of the buttons at the foot of the page.';
$string['pleasesubmityourwork'] = 'Please submit your Work using this Form';
$string['pleaseusethisform'] = 'Please complete this form when you have <br />finished the instructions in the exercise shown below.';
$string['pleaseviewtheexercise'] = 'Please view the exercise given below by clicking on it\'s title.<br />You should follow the instructions in this exercise. <br />When you are happy that you have completed the exercise<br /> successfully you should click on Assess (or Re-assess) link in <br />the box below. When you have done this assessment you will <br />be shown further instructions on submitting your work.';
$string['poor'] = 'Poor';
$string['present'] = 'Present';
$string['reasonforadjustment'] = 'General Comment/Reason for Adjustment';
$string['reassess'] = 'Re-assess';
$string['regradestudentassessments'] = 'Re-grade Student assessments';
$string['resubmissionfor'] = 'Resubmission for $a';
$string['resubmitnote'] = '* means that the $a is allowed to redo this submission. <br /> This flag can be given to any submission by re-assessing it and clicking <br />on the <b>Allow $a to Re-submit</b> button. <br />The student can resubmit when this flag is present on <b>any</b> of their submissions.';
$string['rubric'] = 'Rubric';
$string['savedok'] = 'Saved OK';
$string['saveentries'] = 'Save Entries';
$string['savemyassessment'] = 'Save my Assessment';
$string['saveweights'] = 'Save Weights';
$string['scale10'] = 'Score out of 10';
$string['scale100'] = 'Score out of 100';
$string['scale20'] = 'Score out of 20';
$string['scalecorrect'] = '2 point Correct/Incorrect scale';
$string['scaleexcellent4'] = '4 point Excellent/Very Poor scale';
$string['scaleexcellent5'] = '5 point Excellent/Very Poor scale';
$string['scaleexcellent7'] = '7 point Excellent/Very Poor scale';
$string['scalegood3'] = '3 point Good/Poor scale';
$string['scalepresent'] = '2 point Present/Absent scale';
$string['scaleyes'] = '2 point Yes/No scale';
$string['specimenassessmentform'] = 'Specimen Assessment Form';
$string['standarddeviation'] = 'Standard Deviation';
$string['strict'] = 'Strict';
$string['studentallowedtoresubmit'] = '$a ALLOWED to re-submit';
$string['studentassessments'] = '$a Assessments';
$string['studentnotallowed'] = '$a NOT allowed to re-submit (or not needed)';
$string['studentsubmissions'] = '$a Submissions';
$string['studentsubmissionsforassessment'] = '$a Student Submissions for Assessment';
$string['submission'] = 'Submission';
$string['submissions'] = 'Submissions';
$string['submissionsnowclosed'] = 'Submissions now closed - Submission deadline has passed';
$string['submitexercisedescription'] = 'Submit Exercise Description';
$string['submitted'] = 'Submitted';
$string['submittedby'] = 'Submitted by';
$string['suggestedgrade'] = 'Suggested Grade';
$string['teacherassessment'] = '$a Assessment';
$string['teacherassessmenttable'] = '$a Assessment Table';
$string['teacherscomment'] = 'Teacher\'s Comment';
$string['theexercise'] = 'The Exercise';
$string['theexerciseandthesubmissionby'] = 'The Exercise and the Submission by $a';
$string['thegradeis'] = 'The Grade is $a';
$string['thereisfeedbackfromthe'] = 'There is feedback from the $a';
$string['thisisaresubmission'] = 'This is a Re-submission by $a.<br />Your assessment of their previous submission is shown. <br />After looking at the new submission, please Amend this assessment<br /> and click on one of the buttons at the foot of the page.';
$string['title'] = 'Title';
$string['typeofscale'] = 'Type of Scale';
$string['unassessed'] = '$a Unassessed';
$string['ungradedstudentassessments'] = '$a Ungraded Student Assessments';
$string['usemaximum'] = 'Use Maximum';
$string['usemean'] = 'Use Mean';
$string['usepassword'] = 'Use Password';
$string['verylax'] = 'Very Lax';
$string['verypoor'] = 'Very Poor';
$string['verystrict'] = 'Very Strict';
$string['view'] = 'View';
$string['viewteacherassessment'] = 'View $a Assessment';
$string['warningonamendingelements'] = 'WARNING: There are submitted assessments. <br />Do NOT change the number of elements, the scale types or the element weights.';
$string['weightederrorcount'] = 'Weighted Error Count: $a';
$string['weightforgradingofassessments'] = 'Weight for Grading of Assessments';
$string['weightforteacherassessments'] = 'Weight for $a Assessments';
$string['weights'] = 'Weights';
$string['weightssaved'] = 'Weights Saved';
$string['weightsusedforoverallgrade'] = 'Weights used for Overall Grade';
$string['wrongpassword'] = 'Incorrect password for this Exercise';
$string['yourassessment'] = 'Your Assessment';
$string['yourfeedbackgoeshere'] = 'Your Feedback goes Here';
$string['yoursubmission'] = 'Your Submission';

?>
